@@ -10,8 +10,8 @@ import redis
 import random
 import socket
 import tldextract
-from os import path
 from builtins import str
+from . import bhf_signals
 from builtins import object
 from six import string_types
 from scrapy.http import Request
@@ -57,7 +57,9 @@ class DistributedScheduler(object):
     window = 0  # default window to calculate number of hits
     my_ip = None  # the ip address of the scheduler (if needed)
     old_ip = None  # the old ip for logging
+    signals = None  # scrapy signals
     ip_update_interval = 0  # the interval to update the ip address
+    ip_request_proxy = None
     add_type = None  # add spider type to redis throttle queue key
     add_ip = None  # add spider public ip to redis throttle queue key
     item_retries = 0  # the number of extra tries to get an item
@@ -72,8 +74,8 @@ class DistributedScheduler(object):
     black_domains = []  # the domains to ignore thanks to zookeeper config
 
     def __init__(self, server, persist, update_int, timeout, retries, logger,
-                 hits, window, mod, ip_refresh, add_type, add_ip, ip_regex,
-                 backlog_blacklist, queue_timeout, global_page_per_domain_limit,
+                 signals, hits, window, mod, ip_refresh, ip_proxy, add_type, add_ip,
+                 ip_regex, backlog_blacklist, queue_timeout, global_page_per_domain_limit,
                  global_page_per_domain_limit_timeout, domain_max_page_timeout):
         '''
         Initialize the scheduler
@@ -87,6 +89,7 @@ class DistributedScheduler(object):
         self.moderated = mod
         self.rfp_timeout = timeout
         self.ip_update_interval = ip_refresh
+        self.ip_request_proxy = ip_proxy
         self.add_type = add_type
         self.add_ip = add_ip
         self.item_retries = retries
@@ -101,7 +104,8 @@ class DistributedScheduler(object):
         # set up tldextract
         self.extract = tldextract.TLDExtract()
 
-        self.update_ipaddress()
+        self.signals = signals
+        self.update_ip_address()
 
         # if we need better uuid's mod this line
         self.my_uuid = str(uuid.uuid4()).split('-')[4]
@@ -283,7 +287,7 @@ class DistributedScheduler(object):
 
         return False
 
-    def update_ipaddress(self):
+    def update_ip_address(self):
         '''
         Updates the scheduler so it knows its own ip address
         '''
@@ -291,8 +295,11 @@ class DistributedScheduler(object):
         self.old_ip = self.my_ip
         self.my_ip = '127.0.0.1'
         try:
-            obj = urllib.request.urlopen(settings.get('PUBLIC_IP_URL',
-                                                      'http://ip.42.pl/raw'))
+            req = urllib.request.Request(url=settings.get('PUBLIC_IP_URL',
+                                                          'http://ip.42.pl/raw'))
+            if self.ip_request_proxy is not None:
+                req.set_proxy(self.ip_request_proxy, 'http')
+            obj = urllib.request.urlopen(req)
             results = self.ip_regex.findall(obj.read().decode('utf-8'))
             if len(results) > 0:
                 self.my_ip = results[0]
@@ -307,6 +314,8 @@ class DistributedScheduler(object):
         if self.old_ip != self.my_ip:
             self.logger.info("Changed Public IP: {old} -> {new}".format(
                 old=self.old_ip, new=self.my_ip))
+            if self.old_ip is not None:
+                self.signals.send_catch_log_deferred(signal=bhf_signals.ip_changed)
 
     def report_self(self):
         '''
@@ -321,7 +330,7 @@ class DistributedScheduler(object):
         self.redis_conn.expire(key, self.ip_update_interval * 2)
 
     @classmethod
-    def from_settings(cls, settings):
+    def from_settings(cls, signals, settings):
         server = redis.Redis(host=settings.get('REDIS_HOST'),
                              port=settings.get('REDIS_PORT'),
                              db=settings.get('REDIS_DB'),
@@ -336,6 +345,7 @@ class DistributedScheduler(object):
         mod = settings.get('QUEUE_MODERATED', False)
         timeout = settings.get('DUPEFILTER_TIMEOUT', 600)
         ip_refresh = settings.get('SCHEDULER_IP_REFRESH', 60)
+        ip_proxy = settings.get('SCHEDULER_IP_PROXY')
         add_type = settings.get('SCHEDULER_TYPE_ENABLED', False)
         add_ip = settings.get('SCHEDULER_IP_ENABLED', False)
         retries = settings.get('SCHEUDLER_ITEM_RETRIES', 3)
@@ -365,14 +375,14 @@ class DistributedScheduler(object):
         global_page_per_domain_limit_timeout = settings.get('GLOBAL_PAGE_PER_DOMAIN_LIMIT_TIMEOUT', 600)
         domain_max_page_timeout = settings.get('DOMAIN_MAX_PAGE_TIMEOUT', 600)
 
-        return cls(server, persist, up_int, timeout, retries, logger, hits,
-                   window, mod, ip_refresh, add_type, add_ip, ip_regex,
+        return cls(server, persist, up_int, timeout, retries, logger, signals,
+                   hits, window, mod, ip_refresh, ip_proxy, add_type, add_ip, ip_regex,
                    backlog_blacklist, queue_timeout, global_page_per_domain_limit,
                    global_page_per_domain_limit_timeout, domain_max_page_timeout)
 
     @classmethod
     def from_crawler(cls, crawler):
-        return cls.from_settings(crawler.settings)
+        return cls.from_settings(crawler.signals, crawler.settings)
 
     def open(self, spider):
         self.spider = spider
@@ -526,7 +536,7 @@ class DistributedScheduler(object):
         # update the ip address every so often
         if t - self.update_ip_time > self.ip_update_interval:
             self.update_ip_time = t
-            self.update_ipaddress()
+            self.update_ip_address()
             self.report_self()
 
         item = self.find_item()
