@@ -9,11 +9,10 @@ import base64
 import traceback
 from os import path
 import datetime as dt
-from builtins import bytes, str
 
 from kafka import KafkaProducer
 from kafka.errors import KafkaTimeoutError
-from bhfutils.crawler.items import RawResponseItem, MenuResponseItem
+from bhfutils.crawler.items import RawResponseItem
 
 sys.path.append(path.dirname(path.dirname(path.abspath('utils'))))
 
@@ -60,16 +59,16 @@ class LoggingBeforePipeline(object):
         self.logger.debug("Processing item in LoggingBeforePipeline")
         if isinstance(item, RawResponseItem):
             # make duplicate item, but remove unneeded keys
-            item_copy = dict(item)
-            del item_copy['encoding']
-            del item_copy['attrs']
-            if isinstance(item, MenuResponseItem) and item_copy['status_code'] == 200:
-                del item_copy['groupCategoryName']
-                del item_copy['groupName']
-                del item_copy['groupUrl']
+            item_copy = {}
+            item_copy['url'] = item['url']
+            item_copy['appid'] = item['appid']
+            item_copy['spiderid'] = spider.name
+            item_copy['crawlid'] = item['crawlid']
+            item_copy['statusCode'] = item['statusCode']
+            item_copy['responseUrl'] = item['responseUrl']
+            item_copy['playgroundId'] = item['playgroundId']
             item_copy['logger'] = self.logger.name
             item_copy['action'] = 'emit'
-            item_copy['spiderid'] = spider.name
             self.logger.info('Scraped page', extra=item_copy)
             return item
         else:
@@ -148,7 +147,6 @@ class KafkaPipeline(object):
         Cleans the item to be logged
         '''
         item_copy = dict(item)
-        del item_copy['status_code']
         item_copy['action'] = 'ack'
         item_copy['logger'] = self.logger.name
 
@@ -178,6 +176,12 @@ class KafkaPipeline(object):
         try:
             self.logger.debug("Processing item in KafkaPipeline")
             datum = dict(item)
+            if "url" in datum:
+                del datum["url"]
+            if "responseUrl" in datum:
+                del datum["responseUrl"]
+            if "statusCode" in datum:
+                del datum["statusCode"]
             datum["timestamp"] = self._get_time()
             prefix = self.topic_prefix
 
