@@ -15,4 +15,7 @@ class RedisRetryMiddleware(RetryMiddleware):
             # our priority setup is different from super
             retryreq.meta['priority'] = retryreq.meta['priority'] - 10
 
+            if 'playwright_page_methods' in retryreq.meta:
+                del retryreq.meta['playwright_page_methods']
+
             return retryreq
